SystemOrganization addCategory: #'Zinc-Zodiac'!

TestCase subclass: #ZnHTTPSTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Zodiac'!

!ZnHTTPSTests commentStamp: 'SvenVanCaekenberghe 5/18/2011 14:18' prior: 0!
ZnHTTPSTests.

These require that the ZnZodiacNetworkingUtils socket stream factory is enabled:

	ZnNetworkingUtils default: ZnZodiacNetworkingUtils new.
	
Part of Zinc HTTP Components!

!ZnHTTPSTests class methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/27/2012 13:26'!
generateTestData: size
	"self generateTestData: 1111"
	
	^ String 
		streamContents: [ :stream |
			stream << 'Transfer test file of size '; print: size; << ' bytes.'; lf.
			1 to: size do: [ :each |
				stream nextPutAll: 'Line '; print: each; lf ] ] 
		limitedTo: size ! !

!ZnHTTPSTests class methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 6/27/2012 13:27'!
generateTestFiles
	"self generateTestFiles"
	
	(Integer primesUpTo: 100) do: [ :each | | size |
		size := 1024 * each + each.
		FileStream fileNamed: ('test-', size asString, '.txt') do: [ :stream |
			stream nextPutAll: (self generateTestData: size) ] ]! !

!ZnHTTPSTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 10/2/2012 14:55'!
disabledTestPayPal
	| client |
	self ensureSocketStreamFactory.
	self isNativeSSLPluginPresent ifFalse: [ ^ self ].
	(client := ZnClient new) 
		get: 'https://www.paypal.com'.
	self assert: client isSuccess.
	self assert: (client contents includesSubstring: 'PayPal').
	client close! !

!ZnHTTPSTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 7/4/2012 11:32'!
ensureSocketStreamFactory
	self 
		assert: ZnNetworkingUtils default secureSocketStreamClass notNil
		description: 'Please set a secure socket stream class in ZnNetworkingUtils default or switch to the ZnZodiacNetworkingUtils socket stream factory'! !

!ZnHTTPSTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 7/4/2012 11:32'!
isNativeSSLPluginPresent
	"Return whether the SSL VM plugin can be instanciated and intialized."
	
	^ [ ZdcPluginSSLSession new destroy. true ]
			on: ZdcPluginMissing
			do: [ false ]! !

!ZnHTTPSTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testAmazonAWS
	| client |
	self ensureSocketStreamFactory.
	self isNativeSSLPluginPresent ifFalse: [ ^ self ].
	(client := ZnClient new) 
		get: 'https://aws.amazon.com/'.
	self assert: client isSuccess.
	self assert: (client contents includesSubstring: 'Amazon').
	client close! !

!ZnHTTPSTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testGForceInria
	| client |
	self ensureSocketStreamFactory.
	self isNativeSSLPluginPresent ifFalse: [ ^ self ].
	(client := ZnClient new)
		get: 'http://gforge.inria.fr/frs/?group_id=1299'.
	self assert: client isSuccess.
	self assert: (client contents includesSubstring: 'INRIA').
	client close! !

!ZnHTTPSTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/16/2012 21:51'!
testGetPharoVersion
	| client lastBuildVersion |
	self ensureSocketStreamFactory.
	self isNativeSSLPluginPresent ifFalse: [ ^ self ].
	lastBuildVersion := (client := ZnClient new)
		beOneShot;
		get: 'https://ci.inria.fr/pharo/job/Pharo-2.0/lastSuccessfulBuild/api/xml?xpath=/*/description/text()'.
	self assert: client isSuccess.
	self assert: client response contentType equals: ZnMimeType textPlain.
	self assert: client response contentLength > 0.
	self assert: lastBuildVersion notNil.
	self assert: lastBuildVersion isString.
	self assert: lastBuildVersion size > 0! !

!ZnHTTPSTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testGmailEncrypted
	| client |
	self ensureSocketStreamFactory.
	self isNativeSSLPluginPresent ifFalse: [ ^ self ].  
	(client := ZnClient new) 
		get: 'https://www.gmail.com'.
	self assert: client isSuccess.
	self assert: (client contents includesSubstring: 'Google').    
	self assert: (client contents includesSubstring: 'mail'). 
	client close! !

!ZnHTTPSTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testGoogleEncrypted
	| client |
	self ensureSocketStreamFactory.
	self isNativeSSLPluginPresent ifFalse: [ ^ self ].
	(client := ZnClient new) 
		get: 'https://encrypted.google.com/search?q=Smalltalk'.
	self assert: client isSuccess.
	self assert: (client contents includesSubstring: 'Google').    
	self assert: (client contents includesSubstring: 'Smalltalk').
	client close! !

!ZnHTTPSTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testRequestResponse
	| query stream request response |
	self ensureSocketStreamFactory.
	self isNativeSSLPluginPresent ifFalse: [ ^ self ].
	query := 'Smalltalk'.
	stream := ZdcSecureSocketStream openConnectionToHostNamed: 'encrypted.google.com' port: 443.
	[
		request := ZnRequest get: 'https://encrypted.google.com/search?q=', query.
		stream connect.
		request writeOn: stream.
		stream flush.
		response := ZnResponse readFrom: stream.
	] ensure: [ stream close ].
	self assert: response isSuccess.
	self assert: (response contents includesSubstring: 'Google').   
	self assert: (response contents includesSubstring: 'Smalltalk').   
! !

!ZnHTTPSTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 7/4/2012 11:35'!
testTransfers
	self ensureSocketStreamFactory.
	self isNativeSSLPluginPresent ifFalse: [ ^ self ].
	(Integer primesUpTo: 100) do: [ :each | | size client |
		size := 1024 * each + each.
		(client := ZnClient new)
			https;
			host: 's3-eu-west-1.amazonaws.com';
			addPath: 'public-stfx-eu';
			addPath: ('test-', size asString, '.txt');
			get;
			close.
		self assert: client isSuccess.
		self assert: client response contentType equals: ZnMimeType textPlain.
		self assert: client response contentLength equals: size.
		self 
			assert: client contents 
			equals: (self class generateTestData: size)	]! !

!ZnHTTPSTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 7/4/2012 11:34'!
testTransfersSingleClient
	| client |
	self ensureSocketStreamFactory.
	self isNativeSSLPluginPresent ifFalse: [ ^ self ].
	(client := ZnClient new)
		https;
		host: 's3-eu-west-1.amazonaws.com'.
	(Integer primesUpTo: 100) do: [ :each | | size |
		size := 1024 * each + each.
		client
			url: ('/public-stfx-eu/test-', size asString, '.txt');
			get.
		self assert: client isSuccess.
		self assert: client response contentType equals: ZnMimeType textPlain.
		self assert: client response contentLength equals: size.
		self 
			assert: client contents 
			equals: (self class generateTestData: size)	].
	client close! !

!ZnHTTPSTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testWikimedia
	| client |
	self ensureSocketStreamFactory.
	self isNativeSSLPluginPresent ifFalse: [ ^ self ]. 
	(client := ZnClient new) 
		get: 'https://secure.wikimedia.org/'.
	self assert: client isSuccess.
	self assert: (client contents includesSubstring: 'Wikimedia').
	client close! !

ZnMultiThreadedServer subclass: #ZnSecureServer
	instanceVariableNames: 'certificate'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Zodiac'!

!ZnSecureServer commentStamp: 'SvenVanCaekenberghe 12/13/2011 13:26' prior: 0!
I am ZnSecureServer, an implementation of an HTTPS server.
I am a ZnMultiThreadedServer

(ZnSecureServer on: 1443)
	certificate: '/home/sven/ssl/key-cert.pem';
	logToTranscript;
	start;
	yourself.
	
Disclaimer: this is an experimental proof of concept.!

!ZnSecureServer methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 12/13/2011 13:08'!
certificate
	^ certificate! !

!ZnSecureServer methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 12/13/2011 13:08'!
certificate: anObject
	certificate := anObject! !

!ZnSecureServer methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/4/2013 13:14'!
scheme
	^ #https! !

!ZnSecureServer methodsFor: 'private' stamp: 'SvenVanCaekenberghe 12/13/2011 20:34'!
socketStreamOn: socket
	| stream |
	stream := ZdcSecureSocketStream on: socket.
	stream sslSession certificateName: self certificate.
	stream accept.
	self log debug: 'TLS/SSL accept succeeded.'.
	^ stream! !

ZnNetworkingUtils subclass: #ZnZodiacNetworkingUtils
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Zodiac'!

!ZnZodiacNetworkingUtils commentStamp: 'SvenVanCaekenberghe 5/18/2011 12:40' prior: 0!
ZnZodiacNetworkingUtils is socket and socketstream factory subclassing ZnNetworkingUtils,
instanciating Zodiac socket streams., namely ZdcSocketStream and ZdcSecureSocketStream.

Obviously, this class depends on Zodiac.

ZnNetworkingUtils default: ZnZodiacNetworkingUtils new.

ZnNetworkingUtils default: nil.

Part of Zinc HTTP Components.!

!ZnZodiacNetworkingUtils methodsFor: 'initialize-release' stamp: 'SvenVanCaekenberghe 11/10/2011 13:42'!
initialize 
	super initialize.
	self socketStreamClass: ZdcSocketStream.
	self secureSocketStreamClass: ZdcSecureSocketStream! !
